Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(367)

Unified Diff: content/browser/background_fetch/background_fetch_data_manager.h

Issue 2724783002: Make the BackgroundFetchJobController a per-job object (Closed)
Patch Set: ACTUALLY fix the compile error Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/background_fetch/background_fetch_data_manager.h
diff --git a/content/browser/background_fetch/background_fetch_data_manager.h b/content/browser/background_fetch/background_fetch_data_manager.h
index 708e8f543a3c277baf18ecb7095fedcb06420eab..9261abea1bb7ec39142e46471edf031505749591 100644
--- a/content/browser/background_fetch/background_fetch_data_manager.h
+++ b/content/browser/background_fetch/background_fetch_data_manager.h
@@ -11,13 +11,13 @@
#include "base/macros.h"
#include "content/browser/background_fetch/background_fetch_job_data.h"
+#include "content/browser/background_fetch/background_fetch_job_info.h"
#include "content/common/content_export.h"
#include "url/origin.h"
namespace content {
class BackgroundFetchContext;
-class BackgroundFetchJobInfo;
// The BackgroundFetchDataManager keeps track of all of the outstanding requests
// which are in process in the DownloadManager. When Chromium restarts, it is
@@ -30,27 +30,31 @@ class CONTENT_EXPORT BackgroundFetchDataManager {
~BackgroundFetchDataManager();
// Called by BackgroundFetchContext when a new request is started, this will
- // store all of the necessary metadata to track the request. The lifetime of
- // the returned pointer is tied to the lifetime of the
- // BackgroundFetchDataManager.
- // TODO(harkness): Lifetime should be tied to the lifetime of the associated
- // JobController once there is a JobController per request.
- BackgroundFetchJobData* CreateRequest(
+ // store all of the necessary metadata to track the request.
+ std::unique_ptr<BackgroundFetchJobData> CreateRequest(
const BackgroundFetchJobInfo& job_info,
BackgroundFetchRequestInfos request_infos);
private:
+ void WriteJobToStorage(const BackgroundFetchJobInfo& job_info,
+ BackgroundFetchRequestInfos request_infos);
+
+ BackgroundFetchRequestInfos& ReadRequestsFromStorage(
+ const std::string& job_guid);
+
// BackgroundFetchContext owns this BackgroundFetchDataManager, so the
// DataManager is guaranteed to be destructed before the Context.
BackgroundFetchContext* background_fetch_context_;
// Map from <sw_registration_id, tag> to the JobData for that tag.
using JobIdentifier = std::pair<int64_t, std::string>;
std::map<JobIdentifier, std::string> service_worker_tag_map_;
- // Map of batch guid to the associated BackgroundFetchJobData object.
- std::unordered_map<std::string, std::unique_ptr<BackgroundFetchJobData>>
- batch_map_;
+ // Temporary map to hold data which will be written to storage.
+ // Map from job_guid to JobInfo.
+ std::unordered_map<std::string, BackgroundFetchJobInfo> job_map_;
+ // Map from job_guid to RequestInfos.
+ std::unordered_map<std::string, BackgroundFetchRequestInfos> request_map_;
DISALLOW_COPY_AND_ASSIGN(BackgroundFetchDataManager);
};
@@ -30,27 +30,31 @@ class CONTENT_EXPORT BackgroundFetchDataManager {
// DataManager is guaranteed to be destructed before the Context.
BackgroundFetchContext* background_fetch_context_;
- // Map from <sw_registration_id, tag> to the JobData for that tag.
+ // Map from <sw_registration_id, tag> to the job_guid for that tag.
using JobIdentifier = std::pair<int64_t, std::string>;
std::map<JobIdentifier, std::string> service_worker_tag_map_;

Powered by Google App Engine
This is Rietveld 408576698